<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Texas";
    var qsoPartyUrl = "http://www.txqp.net";
    var overlayUrl = "http://www.no5w.com/OverlayTexasRev04.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Anderson", "ande");
  countySelection.options[1] = new Option("Andrews", "andr");
  countySelection.options[2] = new Option("Angelina", "ange");
  countySelection.options[3] = new Option("Aransas", "aran");
  countySelection.options[4] = new Option("Archer", "arch");
  countySelection.options[5] = new Option("Armstrong", "arms");
  countySelection.options[6] = new Option("Atascosa", "atas");
  countySelection.options[7] = new Option("Austin", "aust");
  countySelection.options[8] = new Option("Bailey", "bail");
  countySelection.options[9] = new Option("Bandera", "band");
  countySelection.options[10] = new Option("Bastrop", "bast");
  countySelection.options[11] = new Option("Baylor", "bayl");
  countySelection.options[12] = new Option("Bee", "bee");
  countySelection.options[13] = new Option("Bell", "bell");
  countySelection.options[14] = new Option("Bexar", "bexa");
  countySelection.options[15] = new Option("Blanco", "blan");
  countySelection.options[16] = new Option("Borden", "bord");
  countySelection.options[17] = new Option("Bosque", "bosq");
  countySelection.options[18] = new Option("Bowie", "bowi");
  countySelection.options[19] = new Option("Brazoria", "bzia");
  countySelection.options[20] = new Option("Brazos", "bzos");
  countySelection.options[21] = new Option("Brewster", "brew");
  countySelection.options[22] = new Option("Briscoe", "bris");
  countySelection.options[23] = new Option("Brooks", "broo");
  countySelection.options[24] = new Option("Brown", "brow");
  countySelection.options[25] = new Option("Burleson", "burl");
  countySelection.options[26] = new Option("Burnet", "burn");
  countySelection.options[27] = new Option("Caldwell", "cald");
  countySelection.options[28] = new Option("Calhoun", "calh");
  countySelection.options[29] = new Option("Callahan", "call");
  countySelection.options[30] = new Option("Cameron", "cmrn");
  countySelection.options[31] = new Option("Camp", "camp");
  countySelection.options[32] = new Option("Carson", "cars");
  countySelection.options[33] = new Option("Cass", "cass");
  countySelection.options[34] = new Option("Castro", "cast");
  countySelection.options[35] = new Option("Chambers", "cham");
  countySelection.options[36] = new Option("Cherokee", "cher");
  countySelection.options[37] = new Option("Childress", "chil");
  countySelection.options[38] = new Option("Clay", "clay");
  countySelection.options[39] = new Option("Cochran", "coch");
  countySelection.options[40] = new Option("Coke", "coke");
  countySelection.options[41] = new Option("Coleman", "cole");
  countySelection.options[42] = new Option("Collin", "coln");
  countySelection.options[43] = new Option("Collingsworth", "colw");
  countySelection.options[44] = new Option("Colorado", "colo");
  countySelection.options[45] = new Option("Comal", "coml");
  countySelection.options[46] = new Option("Comanche", "coma");
  countySelection.options[47] = new Option("Concho", "conc");
  countySelection.options[48] = new Option("Cooke", "cook");
  countySelection.options[49] = new Option("Coryell", "cory");
  countySelection.options[50] = new Option("Cottle", "cott");
  countySelection.options[51] = new Option("Crane", "cran");
  countySelection.options[52] = new Option("Crockett", "croc");
  countySelection.options[53] = new Option("Crosby", "cros");
  countySelection.options[54] = new Option("Culberson", "culb");
  countySelection.options[55] = new Option("Dallam", "dalm");
  countySelection.options[56] = new Option("Dallas", "dals");
  countySelection.options[57] = new Option("Dawson", "daws");
  countySelection.options[58] = new Option("DeafSmith", "dsmi");
  countySelection.options[59] = new Option("Delta", "delt");
  countySelection.options[60] = new Option("Denton", "dent");
  countySelection.options[61] = new Option("Dewitt", "dewi");
  countySelection.options[62] = new Option("Dickens", "dick");
  countySelection.options[63] = new Option("Dimmit", "dimm");
  countySelection.options[64] = new Option("Donley", "donl");
  countySelection.options[65] = new Option("Duval", "duva");
  countySelection.options[66] = new Option("Eastland", "east");
  countySelection.options[67] = new Option("Ector", "ecto");
  countySelection.options[68] = new Option("Edwards", "edwa");
  countySelection.options[69] = new Option("Ellis", "elli");
  countySelection.options[70] = new Option("ElPaso", "epas");
  countySelection.options[71] = new Option("Erath", "erat");
  countySelection.options[72] = new Option("Falls", "fall");
  countySelection.options[73] = new Option("Fannin", "fann");
  countySelection.options[74] = new Option("Fayette", "faye");
  countySelection.options[75] = new Option("Fisher", "fish");
  countySelection.options[76] = new Option("Floyd", "floy");
  countySelection.options[77] = new Option("Foard", "foar");
  countySelection.options[78] = new Option("FortBend", "fben");
  countySelection.options[79] = new Option("Franklin", "fran");
  countySelection.options[80] = new Option("Freestone", "free");
  countySelection.options[81] = new Option("Frio", "frio");
  countySelection.options[82] = new Option("Gaines", "gain");
  countySelection.options[83] = new Option("Galveston", "galv");
  countySelection.options[84] = new Option("Garza", "garz");
  countySelection.options[85] = new Option("Gillespie", "gill");
  countySelection.options[86] = new Option("Glasscock", "glas");
  countySelection.options[87] = new Option("Goliad", "goli");
  countySelection.options[88] = new Option("Gonzales", "gonz");
  countySelection.options[89] = new Option("Gray", "gray");
  countySelection.options[90] = new Option("Grayson", "grsn");
  countySelection.options[91] = new Option("Gregg", "greg");
  countySelection.options[92] = new Option("Grimes", "grim");
  countySelection.options[93] = new Option("Guadalupe", "guad");
  countySelection.options[94] = new Option("Hale", "hale");
  countySelection.options[95] = new Option("Hall", "hall");
  countySelection.options[96] = new Option("Hamilton", "hami");
  countySelection.options[97] = new Option("Hansford", "hans");
  countySelection.options[98] = new Option("Hardeman", "hdmn");
  countySelection.options[99] = new Option("Hardin", "hrdn");
  countySelection.options[100] = new Option("Harris", "harr");
  countySelection.options[101] = new Option("Harrison", "hrsn");
  countySelection.options[102] = new Option("Hartley", "hart");
  countySelection.options[103] = new Option("Haskell", "hask");
  countySelection.options[104] = new Option("Hays", "hays");
  countySelection.options[105] = new Option("Hemphill", "hemp");
  countySelection.options[106] = new Option("Henderson", "hend");
  countySelection.options[107] = new Option("Hidalgo", "hida");
  countySelection.options[108] = new Option("Hill", "hill");
  countySelection.options[109] = new Option("Hockley", "hock");
  countySelection.options[110] = new Option("Hood", "hood");
  countySelection.options[111] = new Option("Hopkins", "hopk");
  countySelection.options[112] = new Option("Houston", "hous");
  countySelection.options[113] = new Option("Howard", "howa");
  countySelection.options[114] = new Option("Hudspeth", "huds");
  countySelection.options[115] = new Option("Hunt", "hunt");
  countySelection.options[116] = new Option("Hutchinson", "hutc");
  countySelection.options[117] = new Option("Irion", "irio");
  countySelection.options[118] = new Option("Jack", "jack");
  countySelection.options[119] = new Option("Jackson", "jksn");
  countySelection.options[120] = new Option("Jasper", "jasp");
  countySelection.options[121] = new Option("JeffDavis", "jdav");
  countySelection.options[122] = new Option("Jefferson", "jeff");
  countySelection.options[123] = new Option("JimHogg", "jhog");
  countySelection.options[124] = new Option("JimWells", "jwel");
  countySelection.options[125] = new Option("Johnson", "john");
  countySelection.options[126] = new Option("Jones", "jone");
  countySelection.options[127] = new Option("Karnes", "karn");
  countySelection.options[128] = new Option("Kaufman", "kauf");
  countySelection.options[129] = new Option("Kendall", "kend");
  countySelection.options[130] = new Option("Kenedy", "keny");
  countySelection.options[131] = new Option("Kent", "kent");
  countySelection.options[132] = new Option("Kerr", "kerr");
  countySelection.options[133] = new Option("Kimble", "kimb");
  countySelection.options[134] = new Option("King", "king");
  countySelection.options[135] = new Option("Kinney", "kinn");
  countySelection.options[136] = new Option("Kleberg", "kleb");
  countySelection.options[137] = new Option("Knox", "knox");
  countySelection.options[138] = new Option("Lamar", "lama");
  countySelection.options[139] = new Option("Lamb", "lamb");
  countySelection.options[140] = new Option("Lampasas", "lamp");
  countySelection.options[141] = new Option("Lasalle", "lsal");
  countySelection.options[142] = new Option("Lavaca", "lava");
  countySelection.options[143] = new Option("Lee", "lee");
  countySelection.options[144] = new Option("Leon", "leon");
  countySelection.options[145] = new Option("Liberty", "libe");
  countySelection.options[146] = new Option("Limestone", "lime");
  countySelection.options[147] = new Option("Lipscomb", "lips");
  countySelection.options[148] = new Option("LiveOak", "livo");
  countySelection.options[149] = new Option("Llano", "llan");
  countySelection.options[150] = new Option("Loving", "lovi");
  countySelection.options[151] = new Option("Lubbock", "lubb");
  countySelection.options[152] = new Option("Lynn", "lynn");
  countySelection.options[153] = new Option("Madison", "madi");
  countySelection.options[154] = new Option("Marion", "mari");
  countySelection.options[155] = new Option("Martin", "mart");
  countySelection.options[156] = new Option("Mason", "maso");
  countySelection.options[157] = new Option("Matagorda", "mata");
  countySelection.options[158] = new Option("Maverick", "mave");
  countySelection.options[159] = new Option("McCulloch", "mcul");
  countySelection.options[160] = new Option("McLennan", "mlen");
  countySelection.options[161] = new Option("McMullen", "mmul");
  countySelection.options[162] = new Option("Medina", "medi");
  countySelection.options[163] = new Option("Menard", "mena");
  countySelection.options[164] = new Option("Midland", "midl");
  countySelection.options[165] = new Option("Milam", "mila");
  countySelection.options[166] = new Option("Mills", "mill");
  countySelection.options[167] = new Option("Mitchell", "mitc");
  countySelection.options[168] = new Option("Montague", "mont");
  countySelection.options[169] = new Option("Montgomery", "mgmy");
  countySelection.options[170] = new Option("Moore", "moor");
  countySelection.options[171] = new Option("Morris", "morr");
  countySelection.options[172] = new Option("Motley", "motl");
  countySelection.options[173] = new Option("Nacogdoches", "naco");
  countySelection.options[174] = new Option("Navarro", "nava");
  countySelection.options[175] = new Option("Newton", "newt");
  countySelection.options[176] = new Option("Nolan", "nola");
  countySelection.options[177] = new Option("Nueces", "nuec");
  countySelection.options[178] = new Option("Ochiltree", "ochi");
  countySelection.options[179] = new Option("Oldham", "oldh");
  countySelection.options[180] = new Option("Orange", "oran");
  countySelection.options[181] = new Option("PaloPinto", "ppin");
  countySelection.options[182] = new Option("Panola", "pano");
  countySelection.options[183] = new Option("Parker", "park");
  countySelection.options[184] = new Option("Parmer", "parm");
  countySelection.options[185] = new Option("Pecos", "peco");
  countySelection.options[186] = new Option("Polk", "polk");
  countySelection.options[187] = new Option("Potter", "pott");
  countySelection.options[188] = new Option("Presidio", "pres");
  countySelection.options[189] = new Option("Rains", "rain");
  countySelection.options[190] = new Option("Randall", "rand");
  countySelection.options[191] = new Option("Reagan", "reag");
  countySelection.options[192] = new Option("Real", "real");
  countySelection.options[193] = new Option("RedRiver", "rriv");
  countySelection.options[194] = new Option("Reeves", "reev");
  countySelection.options[195] = new Option("Refugio", "refu");
  countySelection.options[196] = new Option("Roberts", "robe");
  countySelection.options[197] = new Option("Robertson", "rbsn");
  countySelection.options[198] = new Option("Rockwall", "rock");
  countySelection.options[199] = new Option("Runnels", "runn");
  countySelection.options[200] = new Option("Rusk", "rusk");
  countySelection.options[201] = new Option("Sabine", "sabi");
  countySelection.options[202] = new Option("SanAugustine", "saug");
  countySelection.options[203] = new Option("SanJacinto", "sjac");
  countySelection.options[204] = new Option("SanPatricio", "spat");
  countySelection.options[205] = new Option("SanSaba", "ssab");
  countySelection.options[206] = new Option("Schleicher", "schl");
  countySelection.options[207] = new Option("Scurry", "scur");
  countySelection.options[208] = new Option("Shackelford", "shac");
  countySelection.options[209] = new Option("Shelby", "shel");
  countySelection.options[210] = new Option("Sherman", "shmn");
  countySelection.options[211] = new Option("Smith", "smit");
  countySelection.options[212] = new Option("Somervell", "some");
  countySelection.options[213] = new Option("Starr", "star");
  countySelection.options[214] = new Option("Stephens", "step");
  countySelection.options[215] = new Option("Sterling", "ster");
  countySelection.options[216] = new Option("Stonewall", "ston");
  countySelection.options[217] = new Option("Sutton", "sutt");
  countySelection.options[218] = new Option("Swisher", "swis");
  countySelection.options[219] = new Option("Tarrant", "tarr");
  countySelection.options[220] = new Option("Taylor", "tayl");
  countySelection.options[221] = new Option("Terrell", "terl");
  countySelection.options[222] = new Option("Terry", "tery");
  countySelection.options[223] = new Option("Throckmorton", "thro");
  countySelection.options[224] = new Option("Titus", "titu");
  countySelection.options[225] = new Option("TomGreen", "tgre");
  countySelection.options[226] = new Option("Travis", "trav");
  countySelection.options[227] = new Option("Trinity", "trin");
  countySelection.options[228] = new Option("Tyler", "tyle");
  countySelection.options[229] = new Option("Upshur", "upsh");
  countySelection.options[230] = new Option("Upton", "upto");
  countySelection.options[231] = new Option("Uvalde", "uval");
  countySelection.options[232] = new Option("ValVerde", "vver");
  countySelection.options[233] = new Option("VanZandt", "vzan");
  countySelection.options[234] = new Option("Victoria", "vict");
  countySelection.options[235] = new Option("Walker", "walk");
  countySelection.options[236] = new Option("Waller", "wall");
  countySelection.options[237] = new Option("Ward", "ward");
  countySelection.options[238] = new Option("Washington", "wash");
  countySelection.options[239] = new Option("Webb", "webb");
  countySelection.options[240] = new Option("Wharton", "whar");
  countySelection.options[241] = new Option("Wheeler", "whee");
  countySelection.options[242] = new Option("Wichita", "wich");
  countySelection.options[243] = new Option("Wilbarger", "wilb");
  countySelection.options[244] = new Option("Willacy", "wily");
  countySelection.options[245] = new Option("Williamson", "wmsn");
  countySelection.options[246] = new Option("Wilson", "wlsn");
  countySelection.options[247] = new Option("Winkler", "wink");
  countySelection.options[248] = new Option("Wise", "wise");
  countySelection.options[249] = new Option("Wood", "wood");
  countySelection.options[250] = new Option("Yoakum", "yoak");
  countySelection.options[251] = new Option("Young", "youn");
  countySelection.options[252] = new Option("Zapata", "zapa");
  countySelection.options[253] = new Option("Zavala", "zava");
  addMarker(31.79420000, -95.66200000, "Anderson", "ande");
  addMarker(32.30460000, -102.63800000, "Andrews", "andr");
  addMarker(31.27670000, -94.56760000, "Angelina", "ange");
  addMarker(28.07830000, -97.02600000, "Aransas", "aran");
  addMarker(33.61570000, -98.68730000, "Archer", "arch");
  addMarker(34.96530000, -101.35800000, "Armstrong", "arms");
  addMarker(28.93070000, -98.45160000, "Atascosa", "atas");
  addMarker(29.84920000, -96.31330000, "Austin", "aust");
  addMarker(34.06880000, -102.83100000, "Bailey", "bail");
  addMarker(29.72970000, -99.19110000, "Bandera", "band");
  addMarker(30.10310000, -97.33780000, "Bastrop", "bast");
  addMarker(33.61580000, -99.21430000, "Baylor", "bayl");
  addMarker(28.42450000, -97.73270000, "Bee", "bee");
  addMarker(31.03630000, -97.49200000, "Bell", "bell");
  addMarker(29.43750000, -98.46160000, "Bexar", "bexa");
  addMarker(30.21980000, -98.35860000, "Blanco", "blan");
  addMarker(32.74390000, -101.43200000, "Borden", "bord");
  addMarker(31.89740000, -97.64100000, "Bosque", "bosq");
  addMarker(33.47390000, -94.39500000, "Bowie", "bowi");
  addMarker(29.21180000, -95.46510000, "Brazoria", "bzia");
  addMarker(30.65210000, -96.34180000, "Brazos", "bzos");
  addMarker(29.81900000, -103.06100000, "Brewster", "brew");
  addMarker(34.53030000, -101.20800000, "Briscoe", "bris");
  addMarker(27.02310000, -98.26110000, "Brooks", "broo");
  addMarker(31.76390000, -98.93590000, "Brown", "brow");
  addMarker(30.51310000, -96.61800000, "Burleson", "burl");
  addMarker(30.73060000, -98.14390000, "Burnet", "burn");
  addMarker(29.85220000, -97.60760000, "Caldwell", "cald");
  addMarker(28.39550000, -96.62660000, "Calhoun", "calh");
  addMarker(32.29720000, -99.37270000, "Callahan", "call");
  addMarker(26.12440000, -97.50380000, "Cameron", "cmrn");
  addMarker(32.98980000, -94.93620000, "Camp", "camp");
  addMarker(35.40350000, -101.35500000, "Carson", "cars");
  addMarker(33.09570000, -94.34840000, "Cass", "cass");
  addMarker(34.53050000, -102.26200000, "Castro", "cast");
  addMarker(29.70730000, -94.66790000, "Chambers", "cham");
  addMarker(31.78200000, -95.16390000, "Cherokee", "cher");
  addMarker(34.52970000, -100.20800000, "Childress", "chil");
  addMarker(33.81170000, -98.18470000, "Clay", "clay");
  addMarker(33.60670000, -102.82600000, "Cochran", "coch");
  addMarker(31.88950000, -100.53000000, "Coke", "coke");
  addMarker(31.74590000, -99.45900000, "Coleman", "cole");
  addMarker(33.19360000, -96.56990000, "Collin", "coln");
  addMarker(34.96480000, -100.27100000, "Collingsworth", "colw");
  addMarker(29.60470000, -96.52490000, "Colorado", "colo");
  addMarker(29.81630000, -98.32270000, "Comal", "coml");
  addMarker(31.97270000, -98.54050000, "Comanche", "coma");
  addMarker(31.33360000, -99.85840000, "Concho", "conc");
  addMarker(33.68640000, -97.21520000, "Cooke", "cook");
  addMarker(31.39020000, -97.79930000, "Coryell", "cory");
  addMarker(34.07490000, -100.25800000, "Cottle", "cott");
  addMarker(31.36900000, -102.53400000, "Crane", "cran");
  addMarker(30.68720000, -101.67500000, "Crockett", "croc");
  addMarker(33.61420000, -101.30100000, "Crosby", "cros");
  addMarker(31.33210000, -104.47200000, "Culberson", "culb");
  addMarker(36.27780000, -102.60200000, "Dallam", "dalm");
  addMarker(32.76730000, -96.77630000, "Dallas", "dals");
  addMarker(32.74270000, -101.94900000, "Dawson", "daws");
  addMarker(34.96670000, -102.60500000, "DeafSmith", "dsmi");
  addMarker(33.35690000, -95.58420000, "Delta", "delt");
  addMarker(33.20750000, -97.11630000, "Denton", "dent");
  addMarker(29.09890000, -97.36570000, "Dewitt", "dewi");
  addMarker(33.61640000, -100.77900000, "Dickens", "dick");
  addMarker(28.42300000, -99.75430000, "Dimmit", "dimm");
  addMarker(34.96550000, -100.81500000, "Donley", "donl");
  addMarker(27.66020000, -98.51790000, "Duval", "duva");
  addMarker(32.29670000, -98.79670000, "Eastland", "east");
  addMarker(31.86910000, -102.54300000, "Ector", "ecto");
  addMarker(29.95700000, -100.22800000, "Edwards", "edwa");
  addMarker(32.30160000, -96.73540000, "Ellis", "elli");
  addMarker(31.69470000, -106.30000000, "ElPaso", "epas");
  addMarker(32.21530000, -98.20800000, "Erath", "erat");
  addMarker(31.25420000, -96.93760000, "Falls", "fall");
  addMarker(33.61400000, -96.11430000, "Fannin", "fann");
  addMarker(29.89620000, -96.94390000, "Fayette", "faye");
  addMarker(32.74310000, -100.40200000, "Fisher", "fish");
  addMarker(34.07150000, -101.30300000, "Floyd", "floy");
  addMarker(33.98770000, -99.76150000, "Foard", "foar");
  addMarker(29.52550000, -95.75650000, "FortBend", "fben");
  addMarker(33.17570000, -95.21670000, "Franklin", "fran");
  addMarker(31.71300000, -96.13830000, "Freestone", "free");
  addMarker(28.86610000, -99.10740000, "Frio", "frio");
  addMarker(32.74080000, -102.63400000, "Gaines", "gain");
  addMarker(29.33750000, -94.80200000, "Galveston", "galv");
  addMarker(33.17910000, -101.29800000, "Garza", "garz");
  addMarker(30.31710000, -98.94590000, "Gillespie", "gill");
  addMarker(31.86920000, -101.52000000, "Glasscock", "glas");
  addMarker(28.65690000, -97.46600000, "Goliad", "goli");
  addMarker(29.44720000, -97.49460000, "Gonzales", "gonz");
  addMarker(35.40130000, -100.81200000, "Gray", "gray");
  addMarker(33.67870000, -96.66230000, "Grayson", "grsn");
  addMarker(32.51120000, -94.78350000, "Gregg", "greg");
  addMarker(30.54460000, -95.99620000, "Grimes", "grim");
  addMarker(29.61180000, -97.97120000, "Guadalupe", "guad");
  addMarker(34.06890000, -101.82700000, "Hale", "hale");
  addMarker(34.53050000, -100.68100000, "Hall", "hall");
  addMarker(31.71710000, -98.11510000, "Hamilton", "hami");
  addMarker(36.27740000, -101.35400000, "Hansford", "hans");
  addMarker(34.31750000, -99.73630000, "Hardeman", "hdmn");
  addMarker(30.31220000, -94.40190000, "Hardin", "hrdn");
  addMarker(29.83380000, -95.43520000, "Harris", "harr");
  addMarker(32.55980000, -94.37250000, "Harrison", "hrsn");
  addMarker(35.83900000, -102.60200000, "Hartley", "hart");
  addMarker(33.17800000, -99.73120000, "Haskell", "hask");
  addMarker(30.05440000, -98.00390000, "Hays", "hays");
  addMarker(35.83780000, -100.27100000, "Hemphill", "hemp");
  addMarker(32.18240000, -95.94110000, "Henderson", "hend");
  addMarker(26.41220000, -98.22490000, "Hidalgo", "hida");
  addMarker(31.98720000, -97.10810000, "Hill", "hill");
  addMarker(33.60680000, -102.34600000, "Hockley", "hock");
  addMarker(32.39610000, -97.84190000, "Hood", "hood");
  addMarker(33.16860000, -95.58550000, "Hopkins", "hopk");
  addMarker(31.25940000, -95.36730000, "Houston", "hous");
  addMarker(32.30620000, -101.43500000, "Howard", "howa");
  addMarker(31.31560000, -105.45300000, "Hudspeth", "huds");
  addMarker(33.12350000, -96.07800000, "Hunt", "hunt");
  addMarker(35.83970000, -101.35500000, "Hutchinson", "hutc");
  addMarker(31.30400000, -100.98200000, "Irion", "irio");
  addMarker(33.23420000, -98.17240000, "Jack", "jack");
  addMarker(28.96910000, -96.62390000, "Jackson", "jksn");
  addMarker(30.69990000, -94.16300000, "Jasper", "jasp");
  addMarker(30.75870000, -104.21100000, "JeffDavis", "jdav");
  addMarker(29.87510000, -94.14150000, "Jefferson", "jeff");
  addMarker(27.07130000, -98.68630000, "JimHogg", "jhog");
  addMarker(27.65950000, -98.01230000, "JimWells", "jwel");
  addMarker(32.34450000, -97.35170000, "Johnson", "john");
  addMarker(32.73740000, -99.87920000, "Jones", "jone");
  addMarker(28.94490000, -97.88280000, "Karnes", "karn");
  addMarker(32.59960000, -96.30270000, "Kaufman", "kauf");
  addMarker(29.92780000, -98.66750000, "Kendall", "kend");
  addMarker(26.94090000, -97.63690000, "Kenedy", "keny");
  addMarker(33.18100000, -100.77800000, "Kent", "kent");
  addMarker(30.03620000, -99.33770000, "Kerr", "kerr");
  addMarker(30.49880000, -99.70930000, "Kimble", "kimb");
  addMarker(33.61650000, -100.25500000, "King", "king");
  addMarker(29.35410000, -100.45400000, "Kinney", "kinn");
  addMarker(27.42250000, -97.64090000, "Kleberg", "kleb");
  addMarker(33.61670000, -99.73440000, "Knox", "knox");
  addMarker(33.65610000, -95.58310000, "Lamar", "lama");
  addMarker(34.06900000, -102.35100000, "Lamb", "lamb");
  addMarker(31.24660000, -98.23830000, "Lampasas", "lamp");
  addMarker(28.33900000, -99.09840000, "Lasalle", "lsal");
  addMarker(29.34800000, -96.90030000, "Lavaca", "lava");
  addMarker(30.29460000, -96.98750000, "Lee", "lee");
  addMarker(31.31380000, -95.99350000, "Leon", "leon");
  addMarker(30.18890000, -94.80410000, "Liberty", "libe");
  addMarker(31.51790000, -96.58440000, "Limestone", "lime");
  addMarker(36.27760000, -100.27400000, "Lipscomb", "lips");
  addMarker(28.42180000, -98.07190000, "LiveOak", "livo");
  addMarker(30.70390000, -98.65720000, "Llano", "llan");
  addMarker(31.82600000, -103.65500000, "Loving", "lovi");
  addMarker(33.61000000, -101.82100000, "Lubbock", "lubb");
  addMarker(33.17720000, -101.81600000, "Lynn", "lynn");
  addMarker(30.95860000, -95.92650000, "Madison", "madi");
  addMarker(32.78400000, -94.37540000, "Marion", "mari");
  addMarker(32.30600000, -101.95000000, "Martin", "mart");
  addMarker(30.71960000, -99.22430000, "Mason", "maso");
  addMarker(28.80680000, -95.94160000, "Matagorda", "mata");
  addMarker(28.64160000, -100.39000000, "Maverick", "mave");
  addMarker(31.21720000, -99.34720000, "McCulloch", "mcul");
  addMarker(31.55360000, -97.20320000, "McLennan", "mlen");
  addMarker(28.35050000, -98.56880000, "McMullen", "mmul");
  addMarker(29.39050000, -99.10920000, "Medina", "medi");
  addMarker(30.89920000, -99.80020000, "Menard", "mena");
  addMarker(31.86930000, -102.03200000, "Midland", "midl");
  addMarker(30.78420000, -96.96380000, "Milam", "mila");
  addMarker(31.47710000, -98.63080000, "Mills", "mill");
  addMarker(32.30680000, -100.92200000, "Mitchell", "mitc");
  addMarker(33.71260000, -97.73160000, "Montague", "mont");
  addMarker(30.32900000, -95.46350000, "Montgomery", "mgmy");
  addMarker(35.83780000, -101.89300000, "Moore", "moor");
  addMarker(33.12250000, -94.73600000, "Morris", "morr");
  addMarker(34.07390000, -100.78000000, "Motley", "motl");
  addMarker(31.53490000, -94.63900000, "Nacogdoches", "naco");
  addMarker(32.06240000, -96.47350000, "Navarro", "nava");
  addMarker(30.71460000, -93.71380000, "Newton", "newt");
  addMarker(32.30330000, -100.40600000, "Nolan", "nola");
  addMarker(27.77700000, -97.49380000, "Nueces", "nuec");
  addMarker(36.27810000, -100.81600000, "Ochiltree", "ochi");
  addMarker(35.40530000, -102.60300000, "Oldham", "oldh");
  addMarker(30.05470000, -93.90300000, "Orange", "oran");
  addMarker(32.75980000, -98.31620000, "PaloPinto", "ppin");
  addMarker(32.18380000, -94.30670000, "Panola", "pano");
  addMarker(32.77930000, -97.80510000, "Parker", "park");
  addMarker(34.53000000, -102.78500000, "Parmer", "parm");
  addMarker(30.71200000, -102.67700000, "Pecos", "peco");
  addMarker(30.81790000, -94.86910000, "Polk", "polk");
  addMarker(35.40150000, -101.89500000, "Potter", "pott");
  addMarker(29.94430000, -104.38700000, "Presidio", "pres");
  addMarker(32.84580000, -95.81130000, "Rains", "rain");
  addMarker(34.96540000, -101.89600000, "Randall", "rand");
  addMarker(31.36540000, -101.52200000, "Reagan", "reag");
  addMarker(29.85290000, -99.83350000, "Real", "real");
  addMarker(33.63970000, -95.02420000, "RedRiver", "rriv");
  addMarker(31.38330000, -103.55700000, "Reeves", "reev");
  addMarker(28.30810000, -97.15210000, "Refugio", "refu");
  addMarker(35.83850000, -100.81300000, "Roberts", "robe");
  addMarker(31.02630000, -96.53310000, "Robertson", "rbsn");
  addMarker(32.89780000, -96.40810000, "Rockwall", "rock");
  addMarker(31.82970000, -99.97500000, "Runnels", "runn");
  addMarker(32.12570000, -94.71910000, "Rusk", "rusk");
  addMarker(31.37310000, -93.82460000, "Sabine", "sabi");
  addMarker(31.37640000, -94.19110000, "SanAugustine", "saug");
  addMarker(30.61300000, -95.09440000, "SanJacinto", "sjac");
  addMarker(28.00060000, -97.52180000, "SanPatricio", "spat");
  addMarker(31.20550000, -98.75350000, "SanSaba", "ssab");
  addMarker(30.89740000, -100.53900000, "Schleicher", "schl");
  addMarker(32.74780000, -100.91500000, "Scurry", "scur");
  addMarker(32.73590000, -99.35530000, "Shackelford", "shac");
  addMarker(31.77470000, -94.15690000, "Shelby", "shel");
  addMarker(36.27790000, -101.89300000, "Sherman", "shmn");
  addMarker(32.41120000, -95.28990000, "Smith", "smit");
  addMarker(32.20300000, -97.78000000, "Somervell", "some");
  addMarker(26.51080000, -98.74600000, "Starr", "star");
  addMarker(32.73600000, -98.83580000, "Stephens", "step");
  addMarker(31.82180000, -101.04500000, "Sterling", "ster");
  addMarker(33.17890000, -100.25400000, "Stonewall", "ston");
  addMarker(30.49890000, -100.53900000, "Sutton", "sutt");
  addMarker(34.53030000, -101.73500000, "Swisher", "swis");
  addMarker(32.77140000, -97.29150000, "Tarrant", "tarr");
  addMarker(32.30210000, -99.89070000, "Taylor", "tayl");
  addMarker(30.22040000, -102.10700000, "Terrell", "terl");
  addMarker(33.17410000, -102.33500000, "Terry", "tery");
  addMarker(33.17770000, -99.21170000, "Throckmorton", "thro");
  addMarker(33.19020000, -94.96750000, "Titus", "titu");
  addMarker(31.39580000, -100.69000000, "TomGreen", "tgre");
  addMarker(30.32640000, -97.77130000, "Travis", "trav");
  addMarker(31.10580000, -95.13880000, "Trinity", "trin");
  addMarker(30.79250000, -94.35450000, "Tyler", "tyle");
  addMarker(32.71050000, -94.91290000, "Upshur", "upsh");
  addMarker(31.36580000, -102.04700000, "Upton", "upto");
  addMarker(29.35700000, -99.76210000, "Uvalde", "uval");
  addMarker(29.76320000, -101.23000000, "ValVerde", "vver");
  addMarker(32.59680000, -95.76300000, "VanZandt", "vzan");
  addMarker(28.79490000, -96.97410000, "Victoria", "vict");
  addMarker(30.78130000, -95.59530000, "Walker", "walk");
  addMarker(29.98680000, -95.99750000, "Waller", "wall");
  addMarker(31.45940000, -103.18900000, "Ward", "ward");
  addMarker(30.22140000, -96.43740000, "Washington", "wash");
  addMarker(27.73230000, -99.50510000, "Webb", "webb");
  addMarker(29.29850000, -96.24110000, "Wharton", "whar");
  addMarker(35.40120000, -100.27000000, "Wheeler", "whee");
  addMarker(34.02340000, -98.68770000, "Wichita", "wich");
  addMarker(34.14640000, -99.21400000, "Wilbarger", "wilb");
  addMarker(26.45550000, -97.61400000, "Willacy", "wily");
  addMarker(30.65450000, -97.60260000, "Williamson", "wmsn");
  addMarker(29.16240000, -98.06790000, "Wilson", "wlsn");
  addMarker(31.86920000, -103.06300000, "Winkler", "wink");
  addMarker(33.21210000, -97.65230000, "Wise", "wise");
  addMarker(32.77730000, -95.40770000, "Wood", "wood");
  addMarker(33.17360000, -102.82900000, "Yoakum", "yoak");
  addMarker(33.17490000, -98.68720000, "Young", "youn");
  addMarker(26.94540000, -99.20420000, "Zapata", "zapa");
  addMarker(28.86600000, -99.76150000, "Zavala", "zava");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

